@@ -18,15 +18,18 @@ extern "C" {
 	/*
 	 * Qt side
 	 */
-	void qtStartGuiThread(int argc, char *argv[]);
+	void qtApInit(int argc, char *argv[]);
+	void qtApProcessEvents(void);
+	void qtShowFatalError(const char *msg);
 
-	QImageP qtCreateShadowImage(DWORD *w, DWORD *h, int depth, 
+	QImageP qtCreateShadowImage(DWORD *w, DWORD *h, int *depth, 
 				    void **bits, DWORD *stride);
 	void qtRedrawScreen(int x, int y, int w, int h);
 
 	/*
 	 * X side
 	 */
+	void qtStartAp(int argc, char *argv[]);
 	void qtMouseMotionSendEvent(int x, int y);
 	void qtMouseButtonsSendEvent (int iEventType, int iButton);
 	void qtPushMouseKeyEvent(void);
