@@ -15,7 +15,7 @@ Priority: optional
 Section: Qtopia
 Maintainer: Takuya Murakami <tmurakam@mtd.biglobe.ne.jp>
 Architecture: arm
-Version: 0.0.1
+Version: 0.0.2
 Depends:
 Description: X/Qt Server 
  XFree86 server port over Qtopia.
@@ -26,11 +26,13 @@ mkdir -p opt/QtPalmtop/apps/Applications
 mkdir -p opt/QtPalmtop/bin
 mkdir -p opt/QtPalmtop/pics
 mkdir -p opt/QtPalmtop/i18n/ja
+mkdir -p opt/QtPalmtop/help/html
 mkdir -p opt/QtPalmtop/help/ja/html
 
 cp ../programs/Xserver/Xqt opt/QtPalmtop/bin
 cp ../programs/Xserver/hw/xqt/Xqt.desktop opt/QtPalmtop/apps/Applications
 cp ../programs/Xserver/hw/xqt/Xqt.png opt/QtPalmtop/pics
+iconv --to-code=utf8 ../Xqt.html > opt/QtPalmtop/help/html/Xqt.html
 
 cd ..
 ipkg-build .ipkg-work
